@@ -601,27 +601,6 @@ def FilterCORVISData(sourceCORVISDataframe, country=None, state=None, county=Non
       if us.states.lookup(notState[i]):
         notState[i] = str(us.states.lookup(notState[i]))
 
-  # it's possible the above 'not' filtering set some of our arrays to 'None'.
-  # Address that here.
-
-  # if country is None:
-  #   country = []
-  
-  # if county is None:
-  #   county = []
-
-  # if state is None:
-  #   state = []
-
-  # if notCountry is None:
-  #   notCountry = []
-  
-  # if notCounty is None:
-  #   notCounty = []
-
-  # if notState is None:
-  #   notState = []
-
 
 
   # filter before we aggregate: it's faster!
@@ -671,8 +650,8 @@ def FilterCORVISData(sourceCORVISDataframe, country=None, state=None, county=Non
 
     for colName in sourceCORVISDataframe:
       if not (colName in CORVISAggregatorColumnNames):
-        if (colName in ['Lat', 'Long', 'Population']):
-          aggregatorTuples[colName]='max'
+        if (colName in ['Lat', 'Long']):
+          aggregatorTuples[colName]='mean'
         else:
           aggregatorTuples[colName]='sum'
     
